==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/de_DE.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated-Sharing",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Möchten Sie die externe Freigabe {name} von {owner}@{remote} hinzufügen?",
    "Remote share" : "Externe Freigabe",
    "Remote share password" : "Passwort für die externe Freigabe",
    "Cancel" : "Abbrechen",
    "Add remote share" : "Externe Freigabe hinzufügen",
    "Copy" : "Kopieren",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "⌘-C zum Kopieren drücken.",
    "Press Ctrl-C to copy." : "Ctrl-C zum Kopieren drücken.",
    "Invalid Federated Cloud ID" : "Ungültige Federated-Cloud-ID",
    "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
    "Couldn't establish a federated share." : "Federated-Share konnte nicht aufgebaut werden",
    "Couldn't establish a federated share, maybe the password was wrong." : "Federated-Share konnte nicht aufgebaut werden, da eventuell das Passwort falsch ist.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Anfrage zum Federated-Share war erfolgreich. Sie erhalten eine Einladung. Bitte prüfen Sie Ihre Benachrichtigungen. ",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Federated-Share konnte nicht aufgebaut werden, da der Zielserver eine zu alte Version verwendet (Nextcloud <=9).",
    "It is not allowed to send federated group shares from this server." : "Das Erstellen einer Federated Cloud Freigabe ist von diesem Server aus nicht zugelassen.",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Freigabe von %1$s fehlgeschlagen, da dieses Element schon mit %2$s geteilt wird",
    "Not allowed to create a federated share with the same user" : "Das Erstellen einer Federated Cloud Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
    "File is already shared with %s" : "Datei wird bereits geteilt mit %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Freigabe von %1$s fehlgeschlagen, da %2$s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar oder nutzt ein selbst zertifiziertes Zertifikat.",
    "Could not find share" : "Freigabe konnte nicht gefunden werden",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Sie empfingen \"%3$s\" als eine externe Freigabe von \"%1$s\" (im Auftrag von %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Sie empfingen {share} als eine externe Freigabe von {user} (im Auftrag von {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Sie empfingen \"%3$s\" als eine externe Freigabe von \"%1$s\"",
    "You received {share} as a remote share from {user}" : "Sie empfingen {share} als eine externe Freigabe von {user} ",
    "Accept" : "Akzeptieren",
    "Decline" : "Ablehnen",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Teilen Sie mit mir über meine #Nextcloud Federated-Cloud-ID, siehe %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Teilen Sie mit mir über meine #Nextcloud Federated-Cloud-ID",
    "Sharing" : "Teilen",
    "Federated file sharing" : "Federated Datei-Freigabe",
    "Provide federated file sharing across servers" : "Bietet Federated Datei-Freigaben über Servergrenzen hinweg",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "Open documentation" : "Dokumentation öffnen",
    "Adjust how people can share between servers." : "Definiere wie die Benutzer Inhalte mit anderen Servern teilen können.",
    "Allow users on this server to send shares to other servers" : "Benutzern auf diesem Server das Senden von Freigaben an andere Server erlauben",
    "Allow users on this server to receive shares from other servers" : "Benutzern auf diesem Server das Empfangen von Freigaben von anderen Servern erlauben",
    "Allow users on this server to send shares to groups on other servers" : "Ermöglichen Sie Nutzern dieses Servers Freigaben an Gruppen auf anderen Servern zu senden",
    "Allow users on this server to receive group shares from other servers" : "Ermöglichen Sie Nutzern dieses Servers Gruppen-Freigaben von anderen Servern zu empfangen",
    "Search global and public address book for users" : "Durchsuche globales und öffentliches Adressbuch nach Nutzern",
    "Allow users to publish their data to a global and public address book" : "Erlaube Benutzern ihre Daten an ein globales und öffentliches Adressbuch zu veröffentlichen",
    "Federated Cloud" : "Federated Cloud",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Sie können mit allen Leuten teilen, welche Nextcloud, ownCloud oder Pydio nutzen! Geben Sie einfach deren Federated Cloud ID in den Teilen-Dialog ein. Diese sieht wie folgt aus person@cloud.example.com",
    "Your Federated Cloud ID:" : "Ihre Federated-Cloud-ID:",
    "Share it so your friends can share files with you:" : "Teilen SIe es, so dass Ihre Freunde Dateien mit Ihnen teilen können:",
    "Add to your website" : "Zu Ihrer Web-Seite hinzufügen",
    "Share with me via Nextcloud" : "Teilen Sie mit mir über Nextcloud",
    "HTML Code:" : "HTML-Code:",
    "The mountpoint name contains invalid characters." : "Der Name des Einhängepunktes enthält ungültige Zeichen.",
    "Not allowed to create a federated share with the owner." : "Das Erstellen einer Federated Cloud Freigabe mit dem Benutzer ist nicht erlaubt.",
    "Invalid or untrusted SSL certificate" : "Ungültiges oder nicht vertrauenswürdiges SSL-Zertifikat",
    "Could not authenticate to remote share, password might be wrong" : "Die Authentifizierung an der externen Freigabe konnte nicht erfolgen, das Passwort könnte falsch sein",
    "Storage not valid" : "Speicher ungültig",
    "Federated share added" : "Federated-Share hinzugefügt ",
    "Couldn't add remote share" : "Externe Freigabe konnte nicht hinzu gefügt werden",
    "Sharing %s failed, because this item is already shared with %s" : "Die Freigabe von %s ist fehlgeschlagen, da dieses Objekt schon mit %s geteilt wird",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Freigabe von %s fehlgeschlagen, da %s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar oder nutzt ein selbst zertifiziertes Zertifikat.",
    "Search global and public address book for users and let local users publish their data" : "Globales und öffentliches Adressbuch nach Benutzern durchsuchen und lokale Benutzer ihre Daten veröffentlichen lassen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/de_DE.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated-Sharing",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Möchten Sie die externe Freigabe {name} von {owner}@{remote} hinzufügen?",
    "Remote share" : "Externe Freigabe",
    "Remote share password" : "Passwort für die externe Freigabe",
    "Cancel" : "Abbrechen",
    "Add remote share" : "Externe Freigabe hinzufügen",
    "Copy" : "Kopieren",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "⌘-C zum Kopieren drücken.",
    "Press Ctrl-C to copy." : "Ctrl-C zum Kopieren drücken.",
    "Invalid Federated Cloud ID" : "Ungültige Federated-Cloud-ID",
    "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
    "Couldn't establish a federated share." : "Federated-Share konnte nicht aufgebaut werden",
    "Couldn't establish a federated share, maybe the password was wrong." : "Federated-Share konnte nicht aufgebaut werden, da eventuell das Passwort falsch ist.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Anfrage zum Federated-Share war erfolgreich. Sie erhalten eine Einladung. Bitte prüfen Sie Ihre Benachrichtigungen. ",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Federated-Share konnte nicht aufgebaut werden, da der Zielserver eine zu alte Version verwendet (Nextcloud <=9).",
    "It is not allowed to send federated group shares from this server." : "Das Erstellen einer Federated Cloud Freigabe ist von diesem Server aus nicht zugelassen.",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Freigabe von %1$s fehlgeschlagen, da dieses Element schon mit %2$s geteilt wird",
    "Not allowed to create a federated share with the same user" : "Das Erstellen einer Federated Cloud Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
    "File is already shared with %s" : "Datei wird bereits geteilt mit %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Freigabe von %1$s fehlgeschlagen, da %2$s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar oder nutzt ein selbst zertifiziertes Zertifikat.",
    "Could not find share" : "Freigabe konnte nicht gefunden werden",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Sie empfingen \"%3$s\" als eine externe Freigabe von \"%1$s\" (im Auftrag von %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Sie empfingen {share} als eine externe Freigabe von {user} (im Auftrag von {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Sie empfingen \"%3$s\" als eine externe Freigabe von \"%1$s\"",
    "You received {share} as a remote share from {user}" : "Sie empfingen {share} als eine externe Freigabe von {user} ",
    "Accept" : "Akzeptieren",
    "Decline" : "Ablehnen",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Teilen Sie mit mir über meine #Nextcloud Federated-Cloud-ID, siehe %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Teilen Sie mit mir über meine #Nextcloud Federated-Cloud-ID",
    "Sharing" : "Teilen",
    "Federated file sharing" : "Federated Datei-Freigabe",
    "Provide federated file sharing across servers" : "Bietet Federated Datei-Freigaben über Servergrenzen hinweg",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "Open documentation" : "Dokumentation öffnen",
    "Adjust how people can share between servers." : "Definiere wie die Benutzer Inhalte mit anderen Servern teilen können.",
    "Allow users on this server to send shares to other servers" : "Benutzern auf diesem Server das Senden von Freigaben an andere Server erlauben",
    "Allow users on this server to receive shares from other servers" : "Benutzern auf diesem Server das Empfangen von Freigaben von anderen Servern erlauben",
    "Allow users on this server to send shares to groups on other servers" : "Ermöglichen Sie Nutzern dieses Servers Freigaben an Gruppen auf anderen Servern zu senden",
    "Allow users on this server to receive group shares from other servers" : "Ermöglichen Sie Nutzern dieses Servers Gruppen-Freigaben von anderen Servern zu empfangen",
    "Search global and public address book for users" : "Durchsuche globales und öffentliches Adressbuch nach Nutzern",
    "Allow users to publish their data to a global and public address book" : "Erlaube Benutzern ihre Daten an ein globales und öffentliches Adressbuch zu veröffentlichen",
    "Federated Cloud" : "Federated Cloud",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Sie können mit jedem teilen, der einen Nextcloud-Server oder andere Open Cloud Mesh (OCM) kompatible Server und Dienste verwendet! Geben Sie einfach deren Federated-Cloud-ID in den Teilen-Dialog ein. Diese sieht wie folgt aus: person@cloud.example.com",
    "Your Federated Cloud ID:" : "Ihre Federated-Cloud-ID:",
    "Share it so your friends can share files with you:" : "Teilen SIe es, so dass Ihre Freunde Dateien mit Ihnen teilen können:",
    "Add to your website" : "Zu Ihrer Web-Seite hinzufügen",
    "Share with me via Nextcloud" : "Teilen Sie mit mir über Nextcloud",
    "HTML Code:" : "HTML-Code:",
    "Sharing %s failed, because this item is already shared with %s" : "Die Freigabe von %s ist fehlgeschlagen, da dieses Objekt schon mit %s geteilt wird",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Freigabe von %s fehlgeschlagen, da %s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar oder nutzt ein selbst zertifiziertes Zertifikat."
},
"nplurals=2; plural=(n != 1);");
